@@ -1,8 +1,28 @@
 /*
- * freebsd.c
- * Contains FreeBSD specific stuff
+ * Conky, a system monitor, based on torsmo
  *
- * $Id: freebsd.c 814 2006-12-12 23:21:14Z pkovacs $
+ * Any original torsmo code is licensed under the BSD license
+ *
+ * All code written since the fork of torsmo is licensed under the GPL
+ *
+ * Please see COPYING for details
+ *
+ * Copyright (c) 2005-2007 Brenden Matthews, Philip Kovacs, et. al. (see AUTHORS)
+ * All rights reserved.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>. 
+ *
+ *  $Id: freebsd.c 925 2007-08-22 05:11:06Z mirrorbox $
  */
 
 #include <sys/dkstat.h>
@@ -113,6 +133,19 @@ update_uptime()
 	}
 }
 
+int check_mount(char *s)
+{
+	struct statfs *mntbuf;
+	int i, mntsize;
+
+	mntsize = getmntinfo(&mntbuf, MNT_NOWAIT);
+	for (i = mntsize - 1; i >= 0; i--)
+		if (strcmp(mntbuf[i].f_mntonname, s) == 0)
+			return 1;
+
+	return 0;
+}
+
 void
 update_meminfo()
 {
@@ -172,7 +205,6 @@ update_net_stats()
 			struct ifaddrs *iftmp;
 
 			ns->up = 1;
-			ns->linkstatus = 1;
 			last_recv = ns->recv;
 			last_trans = ns->trans;
 
@@ -213,7 +245,6 @@ update_net_stats()
 			ns->trans_speed = (ns->trans - last_trans) / delta;
 		} else {
 			ns->up = 0;
-			ns->linkstatus = 0;
 		}
 	}
 
@@ -321,7 +352,7 @@ update_cpu_usage()
 }
 
 double
-get_i2c_info(int *fd, int arg, char *devtype, char *type)
+get_sysfs_info(int *fd, int arg, char *devtype, char *type)
 {
 	return (0);
 }
@@ -424,8 +455,21 @@ get_battery_stuff(char *buf, unsigned int n, const char *bat, int item)
 }
 
 int
-open_i2c_sensor(const char *dev, const char *type, int n, int *div,
-		char *devtype)
+get_battery_perct(const char *bat)
+{
+	/* not implemented */
+	return (0);
+}
+
+int
+get_battery_perct_bar(const char *bar)
+{
+	/* not implemented */
+	return (0);
+}
+
+int
+open_sysfs_sensor(const char *dir, const char *dev, const char *type, int n, int *div, char *devtype)
 {
 	return (0);
 }
@@ -530,7 +574,7 @@ get_freq_dynamic(char *p_client_buffer, size_t client_buffer_size,
 	snprintf(p_client_buffer, client_buffer_size, p_format,
 		(float)((cycles[1] - cycles[0]) / microseconds) / divisor);
 #else
-	get_freq(p_client_buffer, client_buffer_size, p_format, divisor);
+	get_freq(p_client_buffer, client_buffer_size, p_format, divisor, 1);
 #endif
 }
 
@@ -568,6 +612,7 @@ update_top()
 	proc_find_top(info.cpu, info.memu);
 }
 
+#if 0
 void
 update_wifi_stats()
 {
@@ -624,6 +669,8 @@ cleanup:
 		close(s);
 	}
 }
+#endif
+
 void
 update_diskio()
 {
@@ -739,7 +786,7 @@ proc_find_top(struct process **cpu, struct process **mem)
 	}
 
 	qsort(processes, j - 1, sizeof (struct process), comparemem);
-	for (i = 0; i < 10; i++) {
+	for (i = 0; i < 10 && i < n_processes; i++) {
 		struct process *tmp, *ttmp;
 
 		tmp = malloc(sizeof (struct process));
@@ -757,7 +804,7 @@ proc_find_top(struct process **cpu, struct process **mem)
 	}
 
 	qsort(processes, j - 1, sizeof (struct process), comparecpu);
-	for (i = 0; i < 10; i++) {
+	for (i = 0; i < 10 && i < n_processes; i++) {
 		struct process *tmp, *ttmp;
 
 		tmp = malloc(sizeof (struct process));
@@ -804,29 +851,40 @@ char
 {
 	int fd;
 	struct apm_info info;
+	char *out;
+
+	out = (char *)calloc(16, sizeof (char));
 
 	fd = open(APMDEV, O_RDONLY);
-	if (fd < 0)
-		return ("ERR");
+	if (fd < 0) {
+		strncpy(out, "ERR", 16);
+		return (out);
+	}
 
 	if (apm_getinfo(fd, &info) != 0) {
 		close(fd);
-		return ("ERR");
+		strncpy(out, "ERR", 16);
+		return (out);
 	}
 	close(fd);
 
 	switch (info.ai_acline) {
 		case 0:
-			return ("off-line");
+			strncpy(out, "off-line", 16);
+			return (out);
 			break;
 		case 1:
-			if (info.ai_batt_stat == 3)
-				return ("charging");
-			else
-				return ("on-line");
+			if (info.ai_batt_stat == 3) {
+				strncpy(out, "charging", 16);
+				return (out);
+			} else {
+				strncpy(out, "on-line", 16);
+				return (out);
+			}
 			break;
 		default:
-			return ("unknown");
+			strncpy(out, "unknown", 16);
+			return (out);
 			break;
 	}
 }
