@@ -1,18 +1,30 @@
 /*
- * top.c a slightly modified wmtop.c -- copied from the WindowMaker and gkrelltop
- * 
- * Modified by Brenden Matthews
+ * Conky, a system monitor, based on torsmo
  *
- * Modified by Adi Zaimi
+ * Any original torsmo code is licensed under the BSD license
  *
- * Derived by Dan Piponi dan@tanelorn.demon.co.uk
- * http://www.tanelorn.demon.co.uk
- * http://wmtop.sourceforge.net 
- * from code originally contained in wmsysmon by Dave Clark 
-(clarkd@skynet.ca)
- * This software is licensed through the GNU General Public License.
- 
- *  $Id: top.h 384 2005-11-10 01:20:19Z boojit $
+ * All code written since the fork of torsmo is licensed under the GPL
+ *
+ * Please see COPYING for details
+ *
+ * Copyright (c) 2005 Adi Zaimi, Dan Piponi <dan@tanelorn.demon.co.uk>,
+ *                    Dave Clark <clarkd@skynet.ca>
+ * Copyright (c) 2005-2007 Brenden Matthews, Philip Kovacs, et. al. (see AUTHORS)
+ * All rights reserved.
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>. 
+ *
+ *  $Id: top.h 904 2007-08-10 19:53:44Z brenden1 $
  */
 
 /*
